==> prestashop_1.4.7.3.zip: prestashop/modules/canadapost/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{canadapost}prestashop>canadapost_9a5872e6530b14c9ec112f0821ce16bb'] = 'Calcul des tarifs Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_a5daea18a1d4214028a538c3bf5a41cc'] = 'Offrez à vos clients différentes méthodes de livraison avec Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_9d7d8be1feb0bc026fffd29bc536364e'] = 'option cURL';
$_MODULE['<{canadapost}prestashop>canadapost_883fa0069f4b0454e2277dd567ab3991'] = '\'Unité de poids (LB ou KG)\'';
$_MODULE['<{canadapost}prestashop>canadapost_5a3ceec65d417f5d92c26dbf0dccc00d'] = '\'Unité de mesure (CM ou IN)\'';
$_MODULE['<{canadapost}prestashop>canadapost_4d470fde8487e755a50e9235e3dc13ab'] = 'doit être configuré pour que le module fonctionne correctement';
$_MODULE['<{canadapost}prestashop>canadapost_2056ed4f6b76a94035f12c041350aa2f'] = 'compte Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_20449d3f0b6c6b9265a5cd2a470a6451'] = 'Poids du colis';
$_MODULE['<{canadapost}prestashop>canadapost_bfc00de34bc04366e7fee516adf7dca5'] = 'Frais additionnels';
$_MODULE['<{canadapost}prestashop>canadapost_386aad80d82f8245e9ef80352a2240e8'] = 'Tous les produits dans un colis';
$_MODULE['<{canadapost}prestashop>canadapost_f35eb2a913a3fd6fd8e661012cf0ebd8'] = 'Un produit par colis';
$_MODULE['<{canadapost}prestashop>canadapost_9c536dc938b99309eab40c9a06fc1c00'] = 'Statut du module Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_df432089df8810e4cb9011b96e6ac862'] = 'Le modue de calcul des tarifs Canada Post est configuré et en ligne!';
$_MODULE['<{canadapost}prestashop>canadapost_1e098f6c7ac70d1b66f48d1a060076a3'] = 'Le modue de calcul des tarifs Canada Post n\'est pas encore configuré, vous devez:';
$_MODULE['<{canadapost}prestashop>canadapost_3e203b9a16f360b88d90bba6eb61ce61'] = 'Remplir le formlaire de l\'onglet \"Configuration générale\"';
$_MODULE['<{canadapost}prestashop>canadapost_8c0987b9315003df7dae7f130e3cf58e'] = 'Choississez les services de livraison disponible';
$_MODULE['<{canadapost}prestashop>canadapost_e20f6d6f13fe70e78f6e2ab488493ccf'] = 'Test de connection webservice';
$_MODULE['<{canadapost}prestashop>canadapost_5378f4ad5f6616fda3ef972deba67f8a'] = 'cURL est activé';
$_MODULE['<{canadapost}prestashop>canadapost_52f4393e1b52ba63e27310ca92ba098c'] = 'Configuration Général';
$_MODULE['<{canadapost}prestashop>canadapost_277d63a9b24a09697e3c64092eaf4353'] = 'Configuration des Catégories';
$_MODULE['<{canadapost}prestashop>canadapost_098eec2cabe2c39c6dec3fc522b6571a'] = 'Configuration des Produits';
$_MODULE['<{canadapost}prestashop>canadapost_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aide';
$_MODULE['<{canadapost}prestashop>canadapost_d2126da975d5b9a5b846efaf57d3fd53'] = 'Configuration générale';
$_MODULE['<{canadapost}prestashop>canadapost_4af6ad356ba7dd056b265944ef91cb5b'] = 'Votre compte Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_db06a2900c66a3a2cb78fe3a470f1b85'] = 'Poids du colis';
$_MODULE['<{canadapost}prestashop>canadapost_0274f749472f365e7d48a501e14793e6'] = 'Frais additionnels';
$_MODULE['<{canadapost}prestashop>canadapost_83ad4fdaf06650e6d9d7ca18f82fb975'] = 'Configuration de localisation';
$_MODULE['<{canadapost}prestashop>canadapost_f489118ea95c746d648d36bb50c226f0'] = 'Unité de poids';
$_MODULE['<{canadapost}prestashop>canadapost_659c95668841b7d6602ead454b28d4ba'] = 'L\'unité de poids de votre magasin (ex: KG ou LBS)';
$_MODULE['<{canadapost}prestashop>canadapost_cc13d156306185fd42a860da3049567c'] = 'Unité de dimension';
$_MODULE['<{canadapost}prestashop>canadapost_f804c2bdebc117d9cde3cddad3b49845'] = 'L\'unité de dimension de votre magasin (ex: CM ou IN)';
$_MODULE['<{canadapost}prestashop>canadapost_2481447d04ae756836d32e3ade240ff4'] = 'Configuration de l\'adresse';
$_MODULE['<{canadapost}prestashop>canadapost_5b179e75d464a04d8a04111131b3a3ca'] = 'Votre adresse ligne 1';
$_MODULE['<{canadapost}prestashop>canadapost_281b2def1a9737b33f88013c94fdfeb8'] = 'Votre adresse ligne 2';
$_MODULE['<{canadapost}prestashop>canadapost_d30f507473129e70c4b962ceccf175cf'] = 'Code postal / zip code';
$_MODULE['<{canadapost}prestashop>canadapost_d0585aac6bb77bb49423b2effca0e067'] = 'Votre ville';
$_MODULE['<{canadapost}prestashop>canadapost_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{canadapost}prestashop>canadapost_f8f5a972333ee726fbe5bb52409c0ed0'] = 'Choississez votre pays ...';
$_MODULE['<{canadapost}prestashop>canadapost_4e9863cf5326e6714388045321665d07'] = 'Choississez votre pays dans la liste';
$_MODULE['<{canadapost}prestashop>canadapost_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{canadapost}prestashop>canadapost_cf1580798f7aba85d519afadf1ffd886'] = 'Choississez votre état ...';
$_MODULE['<{canadapost}prestashop>canadapost_02546d525ab356bd43c91e6b07447496'] = 'Il n\'y a pas d\'état pour ce pays';
$_MODULE['<{canadapost}prestashop>canadapost_0ddc2a5660f7d095fff34d6b93077c80'] = 'Configuration du service';
$_MODULE['<{canadapost}prestashop>canadapost_8d6bd50f3fe3ee2f4513066c25e5fb4a'] = 'Mode de calcul';
$_MODULE['<{canadapost}prestashop>canadapost_79a7b64f7e16759d93ef3e74f1916815'] = 'Utilisation du mode calcul \"Tous les produits dans un seul colis\" utilisera automatiquement la taille et les services de livraison par défaut. Les configurations spécifiques pour les catégories et les produits ne seront pas utilisées.';
$_MODULE['<{canadapost}prestashop>canadapost_5cdd307ba6e260beb4801c0c10e22a3a'] = 'Service de livraison';
$_MODULE['<{canadapost}prestashop>canadapost_78945de8de090e90045d299651a68a9b'] = 'Disponible';
$_MODULE['<{canadapost}prestashop>canadapost_2d25c72c1b18e562f6654fff8e11711e'] = 'Indisponible';
$_MODULE['<{canadapost}prestashop>canadapost_d63e135774e62574e2a1921267dad142'] = 'Choisissez les services de livraison qui seront disponibles pour vos clients.';
$_MODULE['<{canadapost}prestashop>canadapost_cf565402d32b79d33f626252949a6941'] = 'Sauvegarder la configuration';
$_MODULE['<{canadapost}prestashop>canadapost_a438cfa1a870740754c9f4b35130cc04'] = 'Votre compte Canada Post n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_805353d2862ea0e658c9ddda871540fa'] = 'Votre code postal / zip code n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_ef9bd955e165dfb0207877e9fe180aeb'] = 'Votre ville n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_5ecc7697a320f93f3ee8fb4048dbd64c'] = 'Votre pays n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_e7bb7d2ee4d79c9b48cfc443781f00b5'] = 'PrestaShop ne peut pas se connecter aux webservices Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_9d1b485edd50e6fbd288b340b386b07d'] = 'Pas de description d\'erreur trouvé';
$_MODULE['<{canadapost}prestashop>canadapost_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';
$_MODULE['<{canadapost}prestashop>canadapost_b9284bff13acffdd879ef4ac7fca5234'] = 'Configuration non mise à jour';
$_MODULE['<{canadapost}prestashop>canadapost_67e19ffdaa0a11e69349810403a9727e'] = 'Vous devez configurer l\'onglet \"Configuration Générale\"';
$_MODULE['<{canadapost}prestashop>canadapost_a37b48e8684078c0620a997b3baeee9f'] = 'Dans cet onglet, vous pouvez faire une configuration spécifique pour chaque catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_f421827ff72ef9a61fb27aa0de62f1e4'] = 'ID Configuration';
$_MODULE['<{canadapost}prestashop>canadapost_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_20cde117cbc92b9ec1fb4e5bc4a7b9bd'] = 'Frais additionnels';
$_MODULE['<{canadapost}prestashop>canadapost_992a0f0542384f1ee5ef51b7cf4ae6c4'] = 'Services';
$_MODULE['<{canadapost}prestashop>canadapost_06df33001c1d7187fdd81ea1f5b277aa'] = 'Actions';
$_MODULE['<{canadapost}prestashop>canadapost_66001bafca8edd8343802bd20cddc10e'] = 'Il n\'y a pas de configuration spécifique pour les catégories.';
$_MODULE['<{canadapost}prestashop>canadapost_605c5ae9959cfe9cc0b0d630b8d3144f'] = 'Êtes vous sûr de vouloir effacer cette configuration spécifique ?';
$_MODULE['<{canadapost}prestashop>canadapost_3e0cb9fd22b124c0839302fef54762d7'] = 'Mettre à jour une règle';
$_MODULE['<{canadapost}prestashop>canadapost_dd593f8a542ab628cbba98c709255e60'] = 'Ajouter une règle';
$_MODULE['<{canadapost}prestashop>canadapost_7fcafa7c47e984693fcb8a92c0fd1beb'] = 'Choississez une catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_d725c0166e978cc30853996c70440873'] = 'Vous devez choisir une catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_882830cb67e4069370c1be3a1ba4e12a'] = 'Cette catégorie a déjà une configuration spécifique.';
$_MODULE['<{canadapost}prestashop>canadapost_fd0119c2a5fc18aa64887b5b7ab41c19'] = 'Une erreur est survenue, essayez encore.';
$_MODULE['<{canadapost}prestashop>canadapost_20f40087c53c662adfb4e780500eaa15'] = 'Dans cet onglet, vous pouvez faire une configuration spécifique par produit.';
$_MODULE['<{canadapost}prestashop>canadapost_deb10517653c255364175796ace3553f'] = 'Produit';
$_MODULE['<{canadapost}prestashop>canadapost_2119cb0eeb7e202767f9fa56566efc50'] = 'Il n\'y a pas de configuration spécifique pour les produits.';
$_MODULE['<{canadapost}prestashop>canadapost_d53b004866635789a76380f66c87e3df'] = 'Êtes vous sûr de vouloir effacer cette configuration spécifique ?';
$_MODULE['<{canadapost}prestashop>canadapost_3c4d710b56f4318dae775cff80619f84'] = 'Choississez un produit...';
$_MODULE['<{canadapost}prestashop>canadapost_9c07640370e4681bf98638d0c458cd2e'] = 'Vous devez choisir un produit.';
$_MODULE['<{canadapost}prestashop>canadapost_c018b9a37818d15477285eb915590d19'] = 'Ce produit a une configuration spécifique';
$_MODULE['<{canadapost}prestashop>canadapost_73e383f703902e137c2e6d8e2e85cc22'] = 'Bienvenue dans le configateur du module Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_92640c80a67da1782a18304336405dac'] = 'Cette section vous aidera à comprendre comment configurer votre module correctement.';
$_MODULE['<{canadapost}prestashop>canadapost_ec0e6948e8f34818d80f27c309f46661'] = 'Ci-dessous la description de chaque champs :';
$_MODULE['<{canadapost}prestashop>canadapost_a5f7df92d8088761b0727fb1ce0a013a'] = 'Votre compte Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_742e9dca63ccb97a592727c4c2c9abc8'] = 'Vous devez vous inscrire au site Web de Canada Post à cette adresse';
$_MODULE['<{canadapost}prestashop>canadapost_35ba940948fa0ea163fd01281de10e2f'] = 'Ce champ doit être le Zip / code postal de votre point de départ de vos colis.';
$_MODULE['<{canadapost}prestashop>canadapost_81822348ace1ceabad5e9f8992ce9ea4'] = 'Ce champ doit être le pays de votre point de départ de vos colis.';
$_MODULE['<{canadapost}prestashop>canadapost_b9bba478eb4348e49e672e944b072b68'] = 'Ces cases correspondent aux services de livraison que vous voulez rendre disponibles (quand il n\'y a pas de configuration spécifique pour les produits ou les catégories de produits).';
$_MODULE['<{canadapost}prestashop>canadapost_b7c1051bdf970e718e2a3664ad3e31ac'] = 'Cette section vous permet de définir une configuration Canada Post spécifique pour chaque catégorie de produits (tels que les frais supplémentaires).';
$_MODULE['<{canadapost}prestashop>canadapost_2911404cfaf6a4c3a6756e157b0edb62'] = 'Cette section vous permet de définir une configuration Canada Post spécifique pour chaque produit (tels que les frais supplémentaires).';
$_MODULE['<{canadapost}prestashop>canadapost_902b0d55fddef6f8d651fe1035b7d4bd'] = 'Erreur';
$_MODULE['<{canadapost}prestashop>canadapost_43c9c583cfcb8523ad269708ddcde8b8'] = 'Les webservices de Canada Post semblent être injoignables, veuillez reessayer ultérieurement.';
$_MODULE['<{canadapost}prestashop>canadapost_f1c83c0ed9e0f992f7f448f7321d9743'] = 'Les webservices de Canada Post ne répondent pas.';
$_MODULE['<{canadapost}prestashop>canadapost_b7f155fe0169108902b447f572639d0b'] = 'N\'a pas pu se connecter à CanadaPost.com';

==> prestashop_1.4.8.3.zip: prestashop/modules/canadapost/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{canadapost}prestashop>canadapost_9a5872e6530b14c9ec112f0821ce16bb'] = 'Calcul des tarifs Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_a5daea18a1d4214028a538c3bf5a41cc'] = 'Offrez à vos clients différentes méthodes de livraison avec Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_9d7d8be1feb0bc026fffd29bc536364e'] = 'option cURL';
$_MODULE['<{canadapost}prestashop>canadapost_883fa0069f4b0454e2277dd567ab3991'] = '\'Unité de poids (LB ou KG)\'';
$_MODULE['<{canadapost}prestashop>canadapost_5a3ceec65d417f5d92c26dbf0dccc00d'] = '\'Unité de mesure (CM ou IN)\'';
$_MODULE['<{canadapost}prestashop>canadapost_4d470fde8487e755a50e9235e3dc13ab'] = 'doit être configuré pour que le module fonctionne correctement';
$_MODULE['<{canadapost}prestashop>canadapost_2056ed4f6b76a94035f12c041350aa2f'] = 'compte Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_20449d3f0b6c6b9265a5cd2a470a6451'] = 'Poids du colis';
$_MODULE['<{canadapost}prestashop>canadapost_bfc00de34bc04366e7fee516adf7dca5'] = 'Frais additionnels';
$_MODULE['<{canadapost}prestashop>canadapost_386aad80d82f8245e9ef80352a2240e8'] = 'Tous les produits dans un colis';
$_MODULE['<{canadapost}prestashop>canadapost_f35eb2a913a3fd6fd8e661012cf0ebd8'] = 'Un produit par colis';
$_MODULE['<{canadapost}prestashop>canadapost_9c536dc938b99309eab40c9a06fc1c00'] = 'Statut du module Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_df432089df8810e4cb9011b96e6ac862'] = 'Le modue de calcul des tarifs Canada Post est configuré et en ligne!';
$_MODULE['<{canadapost}prestashop>canadapost_1e098f6c7ac70d1b66f48d1a060076a3'] = 'Le modue de calcul des tarifs Canada Post n\'est pas encore configuré, vous devez:';
$_MODULE['<{canadapost}prestashop>canadapost_3e203b9a16f360b88d90bba6eb61ce61'] = 'Remplir le formlaire de l\'onglet \"Configuration générale\"';
$_MODULE['<{canadapost}prestashop>canadapost_8c0987b9315003df7dae7f130e3cf58e'] = 'Choississez les services de livraison disponible';
$_MODULE['<{canadapost}prestashop>canadapost_e20f6d6f13fe70e78f6e2ab488493ccf'] = 'Test de connection webservice';
$_MODULE['<{canadapost}prestashop>canadapost_5378f4ad5f6616fda3ef972deba67f8a'] = 'cURL est activé';
$_MODULE['<{canadapost}prestashop>canadapost_52f4393e1b52ba63e27310ca92ba098c'] = 'Configuration Général';
$_MODULE['<{canadapost}prestashop>canadapost_277d63a9b24a09697e3c64092eaf4353'] = 'Configuration des Catégories';
$_MODULE['<{canadapost}prestashop>canadapost_098eec2cabe2c39c6dec3fc522b6571a'] = 'Configuration des Produits';
$_MODULE['<{canadapost}prestashop>canadapost_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Aide';
$_MODULE['<{canadapost}prestashop>canadapost_d2126da975d5b9a5b846efaf57d3fd53'] = 'Configuration générale';
$_MODULE['<{canadapost}prestashop>canadapost_4af6ad356ba7dd056b265944ef91cb5b'] = 'Votre compte Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_db06a2900c66a3a2cb78fe3a470f1b85'] = 'Poids du colis';
$_MODULE['<{canadapost}prestashop>canadapost_0274f749472f365e7d48a501e14793e6'] = 'Frais additionnels';
$_MODULE['<{canadapost}prestashop>canadapost_83ad4fdaf06650e6d9d7ca18f82fb975'] = 'Configuration de localisation';
$_MODULE['<{canadapost}prestashop>canadapost_f489118ea95c746d648d36bb50c226f0'] = 'Unité de poids';
$_MODULE['<{canadapost}prestashop>canadapost_659c95668841b7d6602ead454b28d4ba'] = 'L\'unité de poids de votre magasin (ex: KG ou LBS)';
$_MODULE['<{canadapost}prestashop>canadapost_cc13d156306185fd42a860da3049567c'] = 'Unité de dimension';
$_MODULE['<{canadapost}prestashop>canadapost_f804c2bdebc117d9cde3cddad3b49845'] = 'L\'unité de dimension de votre magasin (ex: CM ou IN)';
$_MODULE['<{canadapost}prestashop>canadapost_2481447d04ae756836d32e3ade240ff4'] = 'Configuration de l\'adresse';
$_MODULE['<{canadapost}prestashop>canadapost_5b179e75d464a04d8a04111131b3a3ca'] = 'Votre adresse ligne 1';
$_MODULE['<{canadapost}prestashop>canadapost_281b2def1a9737b33f88013c94fdfeb8'] = 'Votre adresse ligne 2';
$_MODULE['<{canadapost}prestashop>canadapost_d30f507473129e70c4b962ceccf175cf'] = 'Code postal / zip code';
$_MODULE['<{canadapost}prestashop>canadapost_d0585aac6bb77bb49423b2effca0e067'] = 'Votre ville';
$_MODULE['<{canadapost}prestashop>canadapost_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{canadapost}prestashop>canadapost_f8f5a972333ee726fbe5bb52409c0ed0'] = 'Choississez votre pays ...';
$_MODULE['<{canadapost}prestashop>canadapost_4e9863cf5326e6714388045321665d07'] = 'Choississez votre pays dans la liste';
$_MODULE['<{canadapost}prestashop>canadapost_46a2a41cc6e552044816a2d04634545d'] = 'Etat';
$_MODULE['<{canadapost}prestashop>canadapost_cf1580798f7aba85d519afadf1ffd886'] = 'Choississez votre état ...';
$_MODULE['<{canadapost}prestashop>canadapost_02546d525ab356bd43c91e6b07447496'] = 'Il n\'y a pas d\'état pour ce pays';
$_MODULE['<{canadapost}prestashop>canadapost_0ddc2a5660f7d095fff34d6b93077c80'] = 'Configuration du service';
$_MODULE['<{canadapost}prestashop>canadapost_8d6bd50f3fe3ee2f4513066c25e5fb4a'] = 'Mode de calcul';
$_MODULE['<{canadapost}prestashop>canadapost_79a7b64f7e16759d93ef3e74f1916815'] = 'Utilisation du mode calcul \"Tous les produits dans un seul colis\" utilisera automatiquement la taille et les services de livraison par défaut. Les configurations spécifiques pour les catégories et les produits ne seront pas utilisées.\"';
$_MODULE['<{canadapost}prestashop>canadapost_5cdd307ba6e260beb4801c0c10e22a3a'] = 'Service de livraison';
$_MODULE['<{canadapost}prestashop>canadapost_78945de8de090e90045d299651a68a9b'] = 'Disponible';
$_MODULE['<{canadapost}prestashop>canadapost_2d25c72c1b18e562f6654fff8e11711e'] = 'Indisponible';
$_MODULE['<{canadapost}prestashop>canadapost_d63e135774e62574e2a1921267dad142'] = 'Choisissez les services de livraison qui seront disponibles pour vos clients.';
$_MODULE['<{canadapost}prestashop>canadapost_cf565402d32b79d33f626252949a6941'] = 'Sauvegarder la configuration';
$_MODULE['<{canadapost}prestashop>canadapost_a438cfa1a870740754c9f4b35130cc04'] = 'Votre compte Canada Post n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_805353d2862ea0e658c9ddda871540fa'] = 'Votre code postal / zip code n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_ef9bd955e165dfb0207877e9fe180aeb'] = 'Votre ville n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_5ecc7697a320f93f3ee8fb4048dbd64c'] = 'Votre pays n\'est pas spécifié';
$_MODULE['<{canadapost}prestashop>canadapost_e7bb7d2ee4d79c9b48cfc443781f00b5'] = 'PrestaShop ne peut pas se connecter aux webservices Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_9d1b485edd50e6fbd288b340b386b07d'] = 'Pas de description d\'erreur trouvé';
$_MODULE['<{canadapost}prestashop>canadapost_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';
$_MODULE['<{canadapost}prestashop>canadapost_b9284bff13acffdd879ef4ac7fca5234'] = 'Configuration non mise à jour';
$_MODULE['<{canadapost}prestashop>canadapost_67e19ffdaa0a11e69349810403a9727e'] = 'Vous devez configurer l\'onglet \"Configuration Générale\"';
$_MODULE['<{canadapost}prestashop>canadapost_a37b48e8684078c0620a997b3baeee9f'] = 'Dans cet onglet, vous pouvez faire une configuration spécifique pour chaque catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_f421827ff72ef9a61fb27aa0de62f1e4'] = 'ID Configuration';
$_MODULE['<{canadapost}prestashop>canadapost_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_20cde117cbc92b9ec1fb4e5bc4a7b9bd'] = 'Frais additionnels';
$_MODULE['<{canadapost}prestashop>canadapost_992a0f0542384f1ee5ef51b7cf4ae6c4'] = 'Services';
$_MODULE['<{canadapost}prestashop>canadapost_06df33001c1d7187fdd81ea1f5b277aa'] = 'Actions';
$_MODULE['<{canadapost}prestashop>canadapost_66001bafca8edd8343802bd20cddc10e'] = 'Il n\'y a pas de configuration spécifique pour les catégories.';
$_MODULE['<{canadapost}prestashop>canadapost_605c5ae9959cfe9cc0b0d630b8d3144f'] = 'Êtes vous sûr de vouloir effacer cette configuration spécifique ?';
$_MODULE['<{canadapost}prestashop>canadapost_3e0cb9fd22b124c0839302fef54762d7'] = 'Mettre à jour une règle';
$_MODULE['<{canadapost}prestashop>canadapost_dd593f8a542ab628cbba98c709255e60'] = 'Ajouter une règle';
$_MODULE['<{canadapost}prestashop>canadapost_7fcafa7c47e984693fcb8a92c0fd1beb'] = 'Choississez une catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_d725c0166e978cc30853996c70440873'] = 'Vous devez choisir une catégorie';
$_MODULE['<{canadapost}prestashop>canadapost_882830cb67e4069370c1be3a1ba4e12a'] = 'Cette catégorie a déjà une configuration spécifique.';
$_MODULE['<{canadapost}prestashop>canadapost_fd0119c2a5fc18aa64887b5b7ab41c19'] = 'Une erreur est survenue, essayez encore.';
$_MODULE['<{canadapost}prestashop>canadapost_20f40087c53c662adfb4e780500eaa15'] = 'Dans cet onglet, vous pouvez faire une configuration spécifique par produit.';
$_MODULE['<{canadapost}prestashop>canadapost_deb10517653c255364175796ace3553f'] = 'Produit';
$_MODULE['<{canadapost}prestashop>canadapost_2119cb0eeb7e202767f9fa56566efc50'] = 'Il n\'y a pas de configuration spécifique pour les produits.';
$_MODULE['<{canadapost}prestashop>canadapost_d53b004866635789a76380f66c87e3df'] = 'Êtes vous sûr de vouloir effacer cette configuration spécifique ?';
$_MODULE['<{canadapost}prestashop>canadapost_3c4d710b56f4318dae775cff80619f84'] = 'Choississez un produit...';
$_MODULE['<{canadapost}prestashop>canadapost_9c07640370e4681bf98638d0c458cd2e'] = 'Vous devez choisir un produit.';
$_MODULE['<{canadapost}prestashop>canadapost_c018b9a37818d15477285eb915590d19'] = 'Ce produit a une configuration spécifique';
$_MODULE['<{canadapost}prestashop>canadapost_73e383f703902e137c2e6d8e2e85cc22'] = 'Bienvenue dans le configateur du module Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_92640c80a67da1782a18304336405dac'] = 'Cette section vous aidera à comprendre comment configurer votre module correctement.';
$_MODULE['<{canadapost}prestashop>canadapost_ec0e6948e8f34818d80f27c309f46661'] = 'Ci-dessous la description de chaque champs :';
$_MODULE['<{canadapost}prestashop>canadapost_a5f7df92d8088761b0727fb1ce0a013a'] = 'Votre compte Canada Post';
$_MODULE['<{canadapost}prestashop>canadapost_742e9dca63ccb97a592727c4c2c9abc8'] = 'Vous devez vous inscrire au site Web de Canada Post à cette adresse';
$_MODULE['<{canadapost}prestashop>canadapost_35ba940948fa0ea163fd01281de10e2f'] = 'Ce champ doit être le Zip / code postal de votre point de départ de vos colis.';
$_MODULE['<{canadapost}prestashop>canadapost_81822348ace1ceabad5e9f8992ce9ea4'] = 'Ce champ doit être le pays de votre point de départ de vos colis.';
$_MODULE['<{canadapost}prestashop>canadapost_b9bba478eb4348e49e672e944b072b68'] = 'Ces cases correspondent aux services de livraison que vous voulez rendre disponibles (quand il n\'y a pas de configuration spécifique pour les produits ou les catégories de produits).';
$_MODULE['<{canadapost}prestashop>canadapost_b7c1051bdf970e718e2a3664ad3e31ac'] = 'Cette section vous permet de définir une configuration Canada Post spécifique pour chaque catégorie de produits (tels que les frais supplémentaires).';
$_MODULE['<{canadapost}prestashop>canadapost_2911404cfaf6a4c3a6756e157b0edb62'] = 'Cette section vous permet de définir une configuration Canada Post spécifique pour chaque produit (tels que les frais supplémentaires).';
$_MODULE['<{canadapost}prestashop>canadapost_902b0d55fddef6f8d651fe1035b7d4bd'] = 'Erreur';
$_MODULE['<{canadapost}prestashop>canadapost_43c9c583cfcb8523ad269708ddcde8b8'] = 'Les webservices de Canada Post semblent être injoignables, veuillez reessayer ultérieurement.';
$_MODULE['<{canadapost}prestashop>canadapost_f1c83c0ed9e0f992f7f448f7321d9743'] = 'Les webservices de Canada Post ne répondent pas.';
$_MODULE['<{canadapost}prestashop>canadapost_b7f155fe0169108902b447f572639d0b'] = 'N\'a pas pu se connecter à CanadaPost.com';
